==> soma_base-5.3.0.tar.gz: soma_base-5.3.0/python/soma/minf/xml_tags.py <==
# -*- coding: utf-8 -*-

#  This software and supporting documentation are distributed by
#      Institut Federatif de Recherche 49
#      CEA/NeuroSpin, Batiment 145,
#      91191 Gif-sur-Yvette cedex
#      France
#
# This software is governed by the CeCILL-B license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/or redistribute the software under the
# terms of the CeCILL-B license as circulated by CEA, CNRS
# and INRIA at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-B license and that you accept its terms.

'''
This module defines only "constants" containing the names of the tags
and the attributes used in XML minf format.

* author: Yann Cointepas
* organization: `NeuroSpin <http://www.neurospin.org>`_
* license: `CeCILL B <http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html>`_
'''
__docformat__ = "restructuredtext en"


noneTag = u'none'
trueTag = u'true'
falseTag = u'false'
numberTag = u'n'
stringTag = u's'
listTag = u'l'
dictionaryTag = u'd'
factoryTag = u'f'
xhtmlTag = u'xhtml'
minfTag = u'minf'
referenceTag = u'ref'

expanderAttribute = u'expander'
lengthAttribute = u'length'
nameAttribute = u'name'
objectTypeAttribute = u'type'
identifierAttribute = u'identifier'

==> soma_base-6.0.0a1.tar.gz: soma_base-6.0.0a1/python/soma/minf/xml_tags.py <==
#  This software and supporting documentation are distributed by
#      Institut Federatif de Recherche 49
#      CEA/NeuroSpin, Batiment 145,
#      91191 Gif-sur-Yvette cedex
#      France
#
# This software is governed by the CeCILL-B license under
# French law and abiding by the rules of distribution of free software.
# You can  use, modify and/or redistribute the software under the
# terms of the CeCILL-B license as circulated by CEA, CNRS
# and INRIA at the following URL "http://www.cecill.info".
#
# As a counterpart to the access to the source code and  rights to copy,
# modify and redistribute granted by the license, users are provided only
# with a limited warranty  and the software's author,  the holder of the
# economic rights,  and the successive licensors  have only  limited
# liability.
#
# In this respect, the user's attention is drawn to the risks associated
# with loading,  using,  modifying and/or developing or reproducing the
# software by the user in light of its specific status of free software,
# that may mean  that it is complicated to manipulate,  and  that  also
# therefore means  that it is reserved for developers  and  experienced
# professionals having in-depth computer knowledge. Users are therefore
# encouraged to load and test the software's suitability as regards their
# requirements in conditions enabling the security of their systems and/or
# data to be ensured and,  more generally, to use and operate it in the
# same conditions as regards security.
#
# The fact that you are presently reading this means that you have had
# knowledge of the CeCILL-B license and that you accept its terms.

"""
This module defines only "constants" containing the names of the tags
and the attributes used in XML minf format.

* author: Yann Cointepas
* organization: `CEA <http://www.cea.fr>`_
* license: `CeCILL B <http://www.cecill.info/licences/Licence_CeCILL-B_V1-en.html>`_
"""

__docformat__ = "restructuredtext en"


noneTag = "none"
trueTag = "true"
falseTag = "false"
numberTag = "n"
stringTag = "s"
listTag = "l"
dictionaryTag = "d"
factoryTag = "f"
xhtmlTag = "xhtml"
minfTag = "minf"
referenceTag = "ref"

expanderAttribute = "expander"
lengthAttribute = "length"
nameAttribute = "name"
objectTypeAttribute = "type"
identifierAttribute = "identifier"
